/*
    Class to contain info about log files.
    Copyright (C) 2010 Robin Atwood

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*/

#include "kmfile.h"
#include <qwidget.h>

KmFile::KmFile() 
{
	mNoTmplt = true;
	mpSocket = 0;
	mMsgFieldCnt = 1;
}

KmFile::~KmFile()
{
}

bool KmFile::operator==( const KmFile &other ) const
{
	return (mFileNm == other.mFileNm);
}

KmFileList::KmFileList()
{
}

KmFileList::~KmFileList()
{
}

KmFile* KmFileList::addFile( const KmFile &rFile )
{
	mFiles << rFile;
	mFileNames << rFile.mFileNm;
	return &mFiles.last();
}

void KmFileList::addFileMap( const QString &s, KmFile *rFile )
{
	mMapFile[s] = rFile;
}

void KmFileList::addObjMap( KProcess *obj, KmFile *pFile )
{
	mMapObject[reinterpret_cast<QObject *>( obj )] = pFile;
}

void KmFileList::addObjMap( QTimer *obj, KmFile *pFile )
{
	mMapObject[reinterpret_cast<QObject *>( obj )] = pFile;
}

bool KmFileList::containsFile(const QString &rFile ) const
{
	return mMapFile.contains( rFile );
}

int KmFileList::count() const
{
	return mFiles.count();
}

KmFile* KmFileList::fileMap( const QString &s )
{
	return mMapFile[s];
}

int KmFileList::indexOf( KmFile &rFile ) const
{
	return mFiles.indexOf( rFile );
}

void KmFileList::move( int from, int to )
{
 mFiles.move( from, to );
 mFileNames.move( from, to );
}

KmFile* KmFileList::objMap( QObject *pSender )
{
	return mMapObject[pSender];
}

void KmFileList::removeFile( const KmFile &rFile )
{
	mFileNames.removeOne( rFile.mFileNm );
	mFiles.removeOne( rFile );
}

void KmFileList::removeFileMap( const QString &s )
{
	mMapFile.remove( s );
}

void KmFileList::removeObjMap( KProcess *obj )
{
	mMapObject.remove( reinterpret_cast<QObject *>( obj ) );
}

void KmFileList::removeObjMap( QTimer *obj )
{
	mMapObject.remove( reinterpret_cast<QObject *>( obj ) );
}

KmFile* KmFileList::file( const int k )
{
	if ( (k > -1) & (k < mFiles.count()) )
		return &mFiles[k];
	else
		return 0;
}

QStringList KmFileList::fileNames() const
{
	return mFileNames;
}

